@@ -38,6 +38,7 @@ use sequoia_openpgp::{
 };
 
 use super::{Result, Error};
+use super::email::EmailAddress;
 
 /// WKD variants.
 ///
@@ -62,51 +63,6 @@ impl Default for Variant {
     }
 }
 
-
-/// Stores the local_part and domain of an email address.
-pub struct EmailAddress {
-    local_part: String,
-    domain: String,
-}
-
-
-impl EmailAddress {
-    /// Returns an EmailAddress from an email address string.
-    ///
-    /// From [draft-koch]:
-    ///
-    ///```text
-    /// To help with the common pattern of using capitalized names
-    /// (e.g. "Joe.Doe@example.org") for mail addresses, and under the
-    /// premise that almost all MTAs treat the local-part case-insensitive
-    /// and that the domain-part is required to be compared
-    /// case-insensitive anyway, all upper-case ASCII characters in a User
-    /// ID are mapped to lowercase.  Non-ASCII characters are not changed.
-    ///```
-    fn from<S: AsRef<str>>(email_address: S) -> Result<Self> {
-        // Ensure that is a valid email address by parsing it and return the
-        // errors that it returns.
-        // This is also done in hagrid.
-        let email_address = email_address.as_ref();
-        let v: Vec<&str> = email_address.split('@').collect();
-        if v.len() != 2 {
-            return Err(Error::MalformedEmail(email_address.into()).into())
-        };
-
-        // Convert domain to lowercase without tailoring, i.e. without taking any
-        // locale into account. See:
-        // https://doc.rust-lang.org/std/primitive.str.html#method.to_lowercase
-        //
-        // Keep the local part as-is as we'll need that to generate WKD URLs.
-        let email = EmailAddress {
-            local_part: v[0].to_string(),
-            domain: v[1].to_lowercase()
-        };
-        Ok(email)
-    }
-}
-
-
 /// Stores the parts needed to create a Web Key Directory URL.
 ///
 /// NOTE: This is a different `Url` than [`url::Url`] (`url` crate) that is
@@ -255,8 +211,7 @@ where
         if let Ok(ref resp) = response {
             if resp.status().is_redirection() {
                 let url = resp.headers().get("Location")
-                    .map(|value| value.to_str().ok())
-                    .flatten()
+                    .and_then(|value| value.to_str().ok())
                     .map(|value| value.parse::<Uri>());
                 if let Some(Ok(url)) = url {
                     return get_following_redirects(client, url, depth - 1).await;
@@ -427,14 +382,9 @@ pub fn insert<P, S, V>(base_path: P, domain: S, variant: V,
     Ok(())
 }
 
+#[derive(Default)]
 struct KeyRing(HashMap<Fingerprint, Cert>);
 
-impl Default for KeyRing {
-    fn default() -> Self {
-        Self(Default::default())
-    }
-}
-
 impl KeyRing {
     fn insert(&mut self, cert: Cert) -> Result<()> {
         let fp = cert.fingerprint();
